#GIT_CMT=d08b02499d2de466b2d607cfcfa6f8406cbaafa3
# Copyright(c) 2015, Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# Python major version.
%{expand: %%define pyver %(python -c 'import sys;print(sys.version[0:3])')}

# Package version
%global package_version 0.2.0

# Kolla user name and group name (DO NOT CHANGE THESE!)
%global kolla_user      kolla
%global kolla_group     %{kolla_user}

# Docker group name
%global docker_group    docker


Summary:        OpenStack Kolla Deployment
Name:           openstack-kolla
Version:        %{package_version}
Release:    59.el6
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla
Source0: openstack-kolla-0.2.0.tar.bz2
BuildArch:      noarch

BuildRequires:  python                      >= 2.6
BuildRequires:  python-setuptools           >= 0.9.8
BuildRequires:  python-pbr                  >= 1.3.0


%description
OpenStack Kolla meta package


%prep
%setup -q -n %{name}-%{version}


%build
# Generate a temporary pkg-info file to make pbr happy
PKGINFO_NAME=$(sed -n -e '/^name/ s/name\s=\s//p' setup.cfg)
PKGINFO_VERSION=$(sed -n -e '/^version/ s/version\s=\s//p' setup.cfg)
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: ${PKGINFO_NAME}
Version: ${PKGINFO_VERSION}
__EOF__

# Build the package
%{__python} setup.py build


%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Create the required directory structures
mkdir -m 0755 -p %{buildroot}%{_sysconfdir}/kolla
cp -r etc/kolla/* %{buildroot}%{_sysconfdir}/kolla/

find %{buildroot}%{_sysconfdir}/kolla/config -type f | xargs chmod 0664
find %{buildroot}%{_sysconfdir}/kolla/config -type d | xargs chmod 0775

chmod 0600 %{buildroot}%{_sysconfdir}/kolla/passwords.yml
mv %{buildroot}%{_sysconfdir}/kolla/globals.yml \
   %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
chmod 0664 %{buildroot}%{_datadir}/kolla/ansible/group_vars/__GLOBAL__

# Create the Kolla sudo file
mkdir -p %{buildroot}%{_sysconfdir}/sudoers.d
_group=%{kolla_group}
cat >%{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user} <<__EOF__
Defaults: %{kolla_user} env_keep += "OS_AUTH_URL OS_TENANT_ID OS_TENANT_NAME OS_PROJECT_NAME"
Defaults: %{kolla_user} env_keep += "OS_USERNAME OS_PASSWORD  OS_REGION_NAME REGISTRY"

Defaults: %{kolla_user} !requiretty
Cmnd_Alias KOLLA_ADMIN_CMDS = ALL
%{kolla_user} ALL = (root) NOPASSWD: KOLLA_ADMIN_CMDS

Defaults: %${_group} !requiretty
Cmnd_Alias KOLLA_CMDS = /usr/bin/ansible, /usr/bin/ansible-playbook, /bin/ls, /bin/id
%${_group} ALL = (%{kolla_user}) NOPASSWD: KOLLA_CMDS
__EOF__
chmod 0600 %{buildroot}%{_sysconfdir}/sudoers.d/%{kolla_user}

mv -f %{buildroot}%{_datadir}/kolla/ansible/inventory \
      %{buildroot}%{_datadir}/kolla/ansible/inventory_samples


%clean
rm -rf %{buildroot}


%files
%defattr(-, root, root)
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst


# Package the Kolla development files
%package -n     openstack-kolla-devel
Summary:        OpenStack Kolla development files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       GitPython                   >= 1.0.1
Requires:       python-gitdb                >= 0.6.4
Requires:       python-pbr                  >= 1.3.0
Requires:       python-jinja2               >= 2.6
Requires:       openstack-kolla-ansible     = %{package_version}


%description -n openstack-kolla-devel
Files used to develop Kolla OpenStack Docker images.


%files -n       openstack-kolla-devel
%exclude %{_datadir}/kolla/ansible
%exclude %{_datadir}/kolla/docs/ansible-deployment.rst
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(0444, root, root) %doc LICENSE
%attr(0444, root, root) %doc README.rst
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-build
%{_datadir}/kolla/
%{python_sitelib}/*



# Package the Kolla dependent files
%package -n     openstack-kolla-ansible
Summary:        OpenStack Kolla Ansible playbooks and supporting files.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sed                         >= 4.2.1
Requires:       ansible                     >= 1.9.2
Requires:       ansible                     <  2.0.0
Requires:       openstack-kolla             = %{package_version}
Requires:       openstack-kolla-preinstall  = %{package_version}

%description -n openstack-kolla-ansible
Ansible playbooks and support files to deploy Kolla in Docker containers.


%files -n       openstack-kolla-ansible
%exclude %{_datadir}/kolla/docs/[b-z0-9A-Z]*
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc LICENSE
%doc %{_datadir}/kolla/docs/ansible-deployment.rst
%config(noreplace) %{_sysconfdir}/kolla
%config(noreplace) %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
%attr(-, root, %{kolla_group}) %{_bindir}/kolla-ansible
%{_datadir}/kolla/ansible


%pre -n         openstack-kolla-ansible
case "$*" in
    0)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    if ! test -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__ && \
         test -f %{_sysconfdir}/kolla/globals.yml
    then
        mv %{_sysconfdir}/kolla/globals.yml \
           %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
        echo '# See: %{_datadir}/kolla/ansible/group_vars/__GLOBAL__' >%{_sysconfdir}/kolla/globals.yml
        chown %{kolla_user}:%{kolla_group} %{_sysconfdir}/kolla/globals.yml
        chmod 0664 %{_sysconfdir}/kolla/globals.yml
    fi
fi
exit 0


%post -n        openstack-kolla-ansible
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Operations to support group / host variables
#
if ! test -d %{_datadir}/kolla/ansible/host_vars
then
    mkdir -m 0775 -p %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/ansible/host_vars
    [[ $? -ne 0 ]] && exit 1
fi
chmod 0775 %{_datadir}/kolla/ansible/group_vars
if test -f %{_sysconfdir}/ansible/ansible.cfg && \
   grep -q '^#.*host_key_checking.*False' %{_sysconfdir}/ansible/ansible.cfg
then
     cp -f -p %{_sysconfdir}/ansible/ansible.cfg \
              %{_sysconfdir}/ansible/ansible.cfg.rpmsave
    sed \
     -i \
     -e 's/^#.*host_key_checking.*=.*/host_key_checking = False/' \
     %{_sysconfdir}/ansible/ansible.cfg
fi

if [[ "${inst_type}" == "update" ]]
then
    if test -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave
    then
        mv -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmsave \
              %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    fi
    #
    # Use the default release tag if not using 'latest' tag
    #
    globals_yml=%{_datadir}/kolla/ansible/group_vars/__GLOBAL__
    if grep -q '^openstack_release.*:' ${globals_yml} && \
       ! grep -q '^openstack_release.*:.*latest.*' ${globals_yml}
    then
        sed -i \
            -e 's/^openstack_release.*:/#openstack_release:/' \
            ${globals_yml}
    fi
    rm -f %{_datadir}/kolla/ansible/group_vars/__GLOBAL__.rpmnew
fi
exit 0


%postun -n      openstack-kolla-ansible
case "$*" in
    0)
        #
        # Remove/Erase package
        #
        inst_type="remove"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    #
    # Change the permissions of the config files (bug 21983235)
    #
    _stat="$(stat --format="%U:%G:%a" %{_sysconfdir}/kolla/config)"
    if [[ "${_stat}" == "%{kolla_user}:%{kolla_group}:755" ]]
    then
        chmod -f -R g+w %{_sysconfdir}/kolla/config
    fi
    _stat="$(stat --format="%U:%G:%a" %{_sysconfdir}/kolla/config)"
    if [[ "${_stat}" == "%{kolla_user}:%{kolla_group}:755" ]]
    then
        chmod -f -R g+w %{_sysconfdir}/kolla/config
    fi
fi
exit 0



# Package the Kolla utility files
%package -n     openstack-kolla-utils
Summary:        OpenStack Kolla utilities.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       openstack-kolla             = %{package_version}


%description -n openstack-kolla-utils
Utilities for use with Kolla containers.


%files -n       openstack-kolla-utils
%attr(-, root, root) %doc LICENSE
%attr(755, root, root) %{_bindir}/docker-ostk



# Package the Kolla dependent files
%package -n     openstack-kolla-preinstall
Summary:        OpenStack Kolla pre-install configuration.
Version:        %{package_version}
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla

Requires:       sudo                        >= 1.7
Requires:       docker-engine               >= 1.10.3
Requires:       docker-engine               <  1.11.0
Requires:       btrfs-progs                 >= 4.2.2

Requires:       python-docker-py            >= 1.3.1
Requires:       python-six                  >= 1.9.0


%description -n openstack-kolla-preinstall
Prepare a system for use by OpenStack Kolla deployments.


%files -n       openstack-kolla-preinstall
%attr(-, root, root) %doc LICENSE
%attr(0600, root, root) %{_sysconfdir}/sudoers.d/%{kolla_user}
%attr(0755, %{kolla_user}, %{kolla_group}) %dir %{_datadir}/kolla


%pre -n         openstack-kolla-preinstall
/usr/sbin/groupadd -f -r %{docker_group} >/dev/null 2>&1
/usr/sbin/groupadd -f -r %{kolla_group}  >/dev/null 2>&1
if ! id %{kolla_user} >/dev/null 2>&1
then
    /usr/sbin/useradd \
      -b %{_datadir} \
      -c 'Kolla User' \
      -g %{kolla_group} \
      -G %{docker_group} \
      -M \
      -N \
      -r \
      %{kolla_user}
    [[ $? -ne 0 ]] && exit 1
    [[ ! -d ~%{kolla_user} ]] && mkdir -p ~%{kolla_user}
    chown -f %{kolla_user}:%{kolla_group} ~%{kolla_user}
    chmod -f 0750 ~%{kolla_user}
fi
exit 0


%post -n        openstack-kolla-preinstall
case "$*" in
    1)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

#
# Setup sudoers for the user
#
if ! grep -q '^#include.*%{_sysconfdir}/sudoers.d' %{_sysconfdir}/sudoers
then
    echo '' >&2
    echo 'WARNING: %{_sysconfdir}/sudoers is NOT including the %{_sysconfdir}/sudoers.d files!!' >&2
    echo '         Appending to %{_sysconfdir}/sudoers directly' >&2
    echo '' >&2
    if ! grep -q '^%{kolla_user}.*NOPASSWD' %{_sysconfdir}/sudoers
    then
        cat %{_sysconfdir}/sudoers.d/%{kolla_user} >>%{_sysconfdir}/sudoers
    fi
fi

#
# Prepare the user for SSH access
#
if ! test -d ~%{kolla_user}/.ssh
then
    mkdir -p -m 0700 ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh
    [[ $? -ne 0 ]] && exit 1
fi
if ! test -f ~%{kolla_user}/.ssh/authorized_keys
then
    touch ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chown %{kolla_user}:%{kolla_group} ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
    chmod 0600 ~%{kolla_user}/.ssh/authorized_keys
    [[ $? -ne 0 ]] && exit 1
fi

#
# Prevent 'Error! pty.fork() failed: out of pty devices' errors by forcing ptmxmode=666
#
if grep -q '^devpts' %{_sysconfdir}/fstab
then
    sed \
     -i \
     -e '/^devpts/ s/\(.*\)\(ptmxmode=[0-9]*\)\(.*\)/\1ptmxmode=666\3/' \
     %{_sysconfdir}/fstab
else
    echo 'devpts                  /dev/pts                devpts  rw,nosuid,noexec,relatime,gid=5,mode=620,ptmxmode=666 0 0' >>%{_sysconfdir}/fstab
fi

#
# If this is an Oracle VM Server, prepare the server
#
if test -x %{_sbindir}/ovm2openstack
then
    if [[ ! -h /run ]]
    then
        [[ -d /run ]] && mv -f /run /run.rpmsave
        ln -s %{_var}/run /run
    fi

    [[ ! -d %{_sharedstatedir}/kolla%{_sharedstatedir}/nova ]] && \
        mkdir -p %{_sharedstatedir}/kolla%{_sharedstatedir}/nova

    [[ ! -e %{_sharedstatedir}/nova ]] && \
        ln -s %{_sharedstatedir}/kolla%{_sharedstatedir}/nova \
              %{_sharedstatedir}/nova

    [[ ! -d %{_sharedstatedir}/nova/instances ]] && \
        mkdir -p %{_sharedstatedir}/nova/instances

    #
    # Ideally this should get migrated into the ovm2openstack script
    #
    for svc in multipathd iscsi iscsid oswatcher ovm-consoled ovs-devmon
    do
        [[ ! -z "$(service ${svc} status 2>/dev/null|grep running)" ]] && \
            service ${svc} stop >/dev/null 2>&1
        [[ ! -z "$(chkconfig --list ${svc} 2>/dev/null|grep on)" ]] && \
            chkconfig ${svc} off >/dev/null 2>&1
        chkconfig --del ${svc} >/dev/null 2>&1
    done

    restart_libvirtd=""
    if ! grep -q '^listen_addr.*127.0.0.1' \
                 %{_sysconfdir}/libvirt/libvirtd.conf >/dev/null 2>&1
    then
         cp -f -p %{_sysconfdir}/libvirt/libvirtd.conf \
                  %{_sysconfdir}/libvirt/libvirtd.conf.rpmsave
        sed \
         -i \
         -e '/#tcp_port/c\tcp_port = "16509"' \
         -e '/#listen_addr/c\listen_addr = "0.0.0.0"' \
         -e '/#unix_sock_ro_perm/c\unix_sock_ro_perms = "0777"' \
         -e '/#unix_sock_rw_perm/c\unix_sock_rw_perms = "0770"' \
         -e '/#unix_sock_dir/c\unix_sock_dir = "/var/run/libvirt"' \
         -e '/#log_level/c\log_level = 3' \
         -e '/#listen_tls/c\listen_tls = 0' \
         -e '/#listen_tcp/c\listen_tcp = 1' \
         -e '/#auth_tcp/c\auth_tcp = "none"' \
         %{_sysconfdir}/libvirt/libvirtd.conf
        sed \
         -i \
         -e '/#LIBVIRTD_ARGS/c\LIBVIRTD_ARGS="--listen"' \
         %{_sysconfdir}/sysconfig/libvirtd
         restart_libvirtd="restart"
    fi

    #
    # Only run the ovm2openstack if it has not been run before
    #
    if [[ ! -f %{_sysconfdir}/sysconfig/ovm2openstack ]]
    then
        %{_sbindir}/ovm2openstack >/dev/null 2>&1
    else
        #
        # ONLY restart libvirtd if the config was actually changed since it
        #      can kill VMs
        #
        if [[ ! -z "${restart_libvirtd}" ]]
        then
            service libvirtd restart >/dev/null 2>&1
        fi
    fi
fi

#
# Start the Docker daemon
#
if test -x %{_sbindir}/systemctl
then
    [[ -z "$(systemctl show docker --property UnitFileState|grep '=enabled')" ]] && \
        systemctl enable docker >/dev/null 2>&1
    [[ -z "$(systemctl show docker --property ActiveState|grep '=active')" ]] && \
        systemctl start  docker >/dev/null 2>&1
else
    [[ -z "$(chkconfig --list docker 2>/dev/null|grep on)" ]] && \
        chkconfig docker on >/dev/null 2>&1
    [[ -z "$(service docker status 2>/dev/null|grep running)" ]] && \
        service docker start >/dev/null 2>&1
fi
exit 0



%changelog
* Tue Apr 26 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.2.0-59.el6
- Ceilometer bootstrapping does not work well with preconfigured mysql database
  access (Vladislav Belogrudov)

* Mon Apr 25 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.2.0-58.el6
- Rebuild it

* Mon Apr 25 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.2.0-57.el6
- Ceilometer bootstraps database on incorrect host with incorrect user and port (Vladislav Belogrudov)  
- Replace internal QA repo with public yum for rabbitmq (Paul Bourke)  
- Fix install of python-novaclient in base (Paul Bourke)  
- Update ceilometer-compute Dockerfile to install libvirt-python for source builds specifically (James McCarthy)  
- Manually install python-novaclient 2.23.3 (Paul Bourke)

* Wed Apr 20 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-56.el6
- Update ceilometer_compute bind mount to be more like others (i.e. nova_compute) and add additional ansible logic for libvirt_type in ceilometer.conf (James McCarthy)  
- Set tempurl in Swift. Bug 23099420 - DefCore requires Swift "tempurl" extension to be configured (Kevin Loughnane)  
- Bug 23130748 - DefCore tests require swift object versioning (Kevin Loughnane)  
- Updates for ceilometer_compute - libvirt-python missing, additional bind mount needed. Related to upstream openstack bug: https://bugs.launchpad.net/ceilometer/+bug/1572015 (James McCarthy)

* Mon Apr 18 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-55.el6
- Require Docker Engine 1.10.3 or layer (less than 1.11) (Wiekus Beukes)  
- Try to get the build working, broken since libguestfs was updated up on Oracle yum (Kevin Loughnane)

* Fri Apr 08 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-54.el6
- Remove tabs from Dockerfiles for consistency (James McCarthy)  
- Default RELEASE_TAG to 2.1.1 (Paul Bourke)

* Wed Apr 06 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.2.0-53.el6
- Check module input for valid IPv4 string (Vladislav Belogrudov)  
- Remove default setting for nova_libvirt_virt_type such that it will not show in kollacli property list. Avoids confusion since this is automatically determined. (James McCarthy)  
- Update connection string to include ceilometer_database_port, rename from o3l-mysql to mysql, and set to this connection type explicitly in template (James McCarthy)

* Tue Apr 05 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-51.el6
- Fix issues with not updating the openstack release (Wiekus Beukes)  
- Remove duplicate notification_driver entry in nova template (James McCarthy)  
- Update glance-api configuration to interoperate with ceilometer (James McCarthy)  
- Enable debug by default in the build (Paul Bourke)  
- Log the SHA of the Git ref for source builds (Paul Bourke)  
- Update some default nova configuration to work with ceilometer (James McCarthy)

* Tue Apr 05 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 0.2.0-50.el6
- Bug 23029477 - Neutron nodes don't work in HA mode - vm loses connection to
  the public net (Kevin Loughnane)

* Fri Apr 01 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-48.el6
- For Neutron, do not set L3 HA = true by default (James McCarthy)

* Fri Apr 01 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-47.el6
- Updated nova.conf.j2, auto adjust for xen hypervisor: live_migration_uri = xen+tcp://%s/ live_migration_flag  = VIR_MIGRATE_UNDEFINE_SOURCE, VIR_MIGRATE_LIVE (James McCarthy)  
- Changed listen address to 0.0.0.0 to allow external connectivity (to help libvirtd support migration) (James McCarthy)

* Thu Mar 31 2016 Paul Bourke <paul.bourke@oracle.com> - 0.2.0-46.el6
- Add bind mount and symlink to offline migration (Paul Bourke)  
- Updated neutron-agents Dockerfile to include keepalived and to ensure the l3_ha is enabled by default (James McCarthy)  
- Fix issue where update is not updating the opensta_release (Wiekus Beukes)  
- Some updates for mysqlcluster differences, only on mysqlcluster nodes, and using api container. (James McCarthy)

* Thu Mar 24 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.2.0-42.el6
- RabbitMQ cluster should work on api interface (Vladislav Belogrudov)  
- Add small script to remove test db / users (Paul Bourke)

* Tue Mar 22 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-41.el6
- Added some missing OVM services to stop and added --del to remove the services completely to prevent them from magically starting up again (Wiekus Beukes)  
- Increase db pool size (Paul Bourke)

* Mon Mar 21 2016 Borne Mace <borne.mace@oracle.com> - 0.2.0-40.el6
- Changed rpm to touch globals.yml after move to avoid missing error on rpm remove. (Borne Mace)  
- Moved some values from globals to all.yml to be more consistent about the location of default values. (Borne Mace)

* Wed Mar 16 2016 Paul Bourke <paul.bourke@oracle.com> - 0.2.0-39.el6
- Use temp file for creds rather than env vars (Paul Bourke)  
- Set WORKDIR in utils image (Paul Bourke)  
- Rename openstack-base to utils, remove utils symlink (Paul Bourke)  
- Changes need to test OVM Shared Storage LiveMigration - Bug 22925908 (Mark Duggan)  
- Murano: use internal url to import initial package (Vladislav Belogrudov)  
- Update libivrt settings in support of live migration. (James McCarthy)

* Tue Mar 15 2016 Borne Mace <borne.mace@oracle.com> - 0.2.0-38.el6
- Fixed ostk-docker reference to globals.yml to point to new location in
  /usr/share/kolla (Borne Mace)

* Mon Mar 14 2016 Borne Mace <borne.mace@oracle.com> - 0.2.0-37.el6
- Changed global property handling and moved to correct rpm post section (Borne Mace)  
- neutron-linuxbridge-agent missing ipset and bridgeutils (Mick Thompson)

* Tue Mar 08 2016 Borne Mace <borne.mace@oracle.com> - 0.2.0-36.el6
- Removed extra white spaces (Borne Mace)  
- Updated rpm with operations to support group / host variables (Borne Mace)  
- Added oswatcher to the list of services to stop/disable (Wiekus Beukes)

* Mon Mar 07 2016 Paul Bourke <paul.bourke@oracle.com> - 0.2.0-35.el6
- Add protection to prevent upgrade being run twice (Paul Bourke)  
- Reducing logging level from 2 to 3 (Warning) in libvirtd.conf (Mark Duggan)  
- docker-ostk cannot handle multibyte names (change locale from POSIX to UTF-8) (Mick Thompson)  
- Revert "Add upgrade task to migrate /var/lib/glance to namespace" (Paul Bourke)

* Thu Mar 03 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-34.el6
- Prioritise interface_checks and adjust error msg to be more clear (James McCarthy)  
- Add basic checking for network_interface to prechecks (James McCarthy)  
- Add .reviewboardrc to .gitignore (Paul Bourke)

* Wed Mar 02 2016 Kevin Loughnane <kevin.loughnane@oracle.com> - 0.2.0-33.el6
- Add explicit Blank Line.  Bug 22334507 - MySQL cluster fail to support 3 byte
  utf-8 character (Kevin Loughnane)

* Wed Mar 02 2016 Mick Thompson <michael.a.thompson@oracle.com> - 0.2.0-32.el6
- MySQL cluster fail to support 3 byte utf-8 character (Mick Thompson)

* Tue Mar 01 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-31.el6
- Add enable_swift_rsyncd to all.yml defaults similar to other swift components. (James McCarthy)  
- Neutron Config: Need support for multiple external/public networks (Mick Thompson)

* Thu Feb 25 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-30.el6
- Rebuild it

* Thu Feb 25 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-29.el6
- Force the btrfs-progs to match up with the kernel versions (Wiekus Beukes)  
- Fix up vars showing in upgrade task names (Paul Bourke)

* Tue Feb 23 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-28.el6
- Fix update issues Fix issue where libvirtd is always restarted Update the openstack_release if need be when updating Fix ptmx permission (Wiekus Beukes)  
- Minor Changes for libvirtd.conf on OVM ComputeNode (log level & close TCP ports) (root)  
- Add ansible 2 rpm manually for now (Paul Bourke)

* Thu Feb 18 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-27.el6
- - Added back the OL7 required pieces - Changed OVMS check to work under kickstart - Make the post be repeatable to allow RPM updates (Wiekus Beukes)  
- Remove ca-artifacts refs for openvswitch + pip (Paul Bourke)  
- Revert "Bug 21836881: include the zfssaiscsi  ZFS iscsi Driver in Cinder" (Paul Bourke)  
- Revert "Bug 21836881: include the zfssaiscsi  ZFS iscsi Driver in Cinder" (Paul Bourke)

* Wed Feb 17 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-26.el6
- Changes required to preinstall rpm for OVM Server (bug 22731949) (James McCarthy)  
- Additional mount to /var/lock needed by ovm to help support cinder (James McCarthy)

* Fri Feb 12 2016 Alexander Reunov <alexander.reunov@oracle.com> - 0.2.0-25.el6
- NOVA_LIBVIRT LOG IS MISSED (Mick Thompson)  
- ceilometer: add mongodb settings as a database backend (Alexander Reunov)

* Thu Feb 11 2016 root <root@buildsys.localdomain> - 0.2.0-24.el6
- Add OVM server changes to openstack-kolla-preinstall rpm (root)

* Thu Feb 11 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 0.2.0-23.el6
- Only check absence of libvirt on Xen (Vladislav Belogrudov)  
- Check kolla-preinstall instead of docker and docker-py (Vladislav Belogrudov)

* Wed Feb 10 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-22.el6
- Build it

* Wed Feb 10 2016 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.2.0-21.el6
- Lock down the Ansible Release to 1.9.x (Wiekus Beukes)  
- If the hypervisor type is xen, do not deploy the libvirt container (James McCarthy)  
- Correcting permissions on start and config-external scripts. (Mick Thompson)  
- ConfigFlexibility: Tokenise more config variables (Mick Thompson)

* Tue Feb 09 2016 Mick Thompson <michael.a.thompson@oracle.com> - 0.2.0-20.el6
- Require multipath support for compute nodes (Mick Thompson)

* Tue Feb 09 2016 Alexander Reunov <reunov.hv@gmail.com> - 0.2.0-19.el6
- Jira-Issue: OPENSTACK-618 kollacli unable to launch ceilometer-alarm-* (Alexander Reunov)  
- nova boot: config-drive doesn't work (need "genisoimage" RPM in "nova_compute") (Mick Thompson)  
- Allow Docker 1.10 to be used as well... (Wiekus Beukes)  
- Move memcached to site.yml instead of role dependency (Vladislav Belogrudov)

* Sat Feb 06 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-18.el6
- Build it

* Fri Feb 05 2016 James McCarthy <james.m.mccarthy@oracle.com> - 0.2.0-17.el6
- Update the nova-compute volumes (globally) to accommodate OVM Server (James McCarthy)  
- Fix missing nova instances dir in host mount (Paul Bourke)  
- Add enable_isolated_metadata config to dhcp_agent.ini (Kevin Loughnane)  
- Move network_interface/neutron_external_interface from globals.yml (Paul Bourke)

* Thu Feb 04 2016 Borne Mace <borne.mace@oracle.com> - 0.2.0-16.el6
- Modified precheck playbook for cli usage (Borne Mace)  
- Add upgrade task to migrate mysqlcluster_data to host mounts (Paul Bourke)  
- Add upgrade task to migrate rabbitmq_data to host mounts (Paul Bourke)  
- Add upgrade task to migrate /var/lib/glance to namespace (Paul Bourke)  
- Add upgrade task to migrate cinder_data volumes to host mounts (Paul Bourke)  
- Add upgrade task to migrate nova_data volumes to host mounts (Paul Bourke)  
- Oracle build profile incorrectly includes 'openstack-base' (Vladislav Belogrudov)  
- libguestfs-tools missing in nova-compute container (Mick Thompson)  
- Update MySQL Cluster from 7.4.6-1 to 7.4.10 (Mick Thompson)

* Fri Nov 06 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixed /etc/kolla/config file permissions (bug 21983235)
- Fixed user creation issues (bug 22098605)

* Fri Oct 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Renamed the kolla-tools package to kolla-utils
- Added a check to make sure sudoers.d gets inlcuded by sudoers

* Wed Sep 23 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added the kolla-tools package

* Tue Sep 15 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added OL6 support

* Thu Sep 10 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Changed the useradd to not create the home dir and only create it if need be
- Renamed the inventory directory inventory_samples

* Tue Sep 08 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Changed %config to %config(noreplace)

* Fri Sep 04 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixing file permissions and leaving kolla user alone on uninstall
- Fixed issue where post would sometime error exiting
- Changed the SSH dir create to be post rather then forcefully laying it down
- Change the Ansible config file to disable host key checking

* Wed Sep 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Initial release

